# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpdateCompound(BaseModel):
    update_compound: Optional["UpdateCompoundUpdateCompound"] = Field(
        alias="updateCompound"
    )


class UpdateCompoundUpdateCompound(BaseModel):
    id: str
    name: str
    description: Optional[str]
    aliases: list[str]


UpdateCompound.model_rebuild()
