# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class AllUsers(BaseModel):
    all_users: list["AllUsersAllUsers"] = Field(alias="allUsers")


class AllUsersAllUsers(BaseModel):
    id: str
    email: str
    name: Optional[str]
    role: str


AllUsers.model_rebuild()
