# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class CreateCaseStudy(BaseModel):
    create_case_study: "CreateCaseStudyCreateCaseStudy" = Field(alias="createCaseStudy")


class CreateCaseStudyCreateCaseStudy(BaseModel):
    id: str
    title: str
    summary: str
    url: Optional[str]
    source_type: str = Field(alias="sourceType")


CreateCaseStudy.model_rebuild()
