# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class DeleteUser(BaseModel):
    delete_user: "DeleteUserDeleteUser" = Field(alias="deleteUser")


class DeleteUserDeleteUser(BaseModel):
    message: str
    success: Optional[bool]


DeleteUser.model_rebuild()
