# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class EmbedBusinessDescription(BaseModel):
    embed_business_description: "EmbedBusinessDescriptionEmbedBusinessDescription" = (
        Field(alias="embedBusinessDescription")
    )


class EmbedBusinessDescriptionEmbedBusinessDescription(BaseModel):
    id: str
    name: str
    description: Optional[str]


EmbedBusinessDescription.model_rebuild()
