# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import ProtocolCategory


class CreateProtocol(BaseModel):
    create_protocol: "CreateProtocolCreateProtocol" = Field(alias="createProtocol")


class CreateProtocolCreateProtocol(BaseModel):
    id: str
    name: str
    description: Optional[str]
    categories: list[ProtocolCategory]
    goals: list[str]


CreateProtocol.model_rebuild()
