# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class CreateBusinessWithRelations(BaseModel):
    create_business_with_relations: (
        "CreateBusinessWithRelationsCreateBusinessWithRelations"
    ) = Field(alias="createBusinessWithRelations")


class CreateBusinessWithRelationsCreateBusinessWithRelations(BaseModel):
    id: str
    name: str
    description: Optional[str]
    website: Optional[str]


CreateBusinessWithRelations.model_rebuild()
