# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpdateProtocolRelations(BaseModel):
    update_protocol_relations: Optional[
        "UpdateProtocolRelationsUpdateProtocolRelations"
    ] = Field(alias="updateProtocolRelations")


class UpdateProtocolRelationsUpdateProtocolRelations(BaseModel):
    id: str
    name: str
    products: list["UpdateProtocolRelationsUpdateProtocolRelationsProducts"]
    compounds: list["UpdateProtocolRelationsUpdateProtocolRelationsCompounds"]


class UpdateProtocolRelationsUpdateProtocolRelationsProducts(BaseModel):
    id: str
    name: str


class UpdateProtocolRelationsUpdateProtocolRelationsCompounds(BaseModel):
    id: str
    name: str


UpdateProtocolRelations.model_rebuild()
UpdateProtocolRelationsUpdateProtocolRelations.model_rebuild()
