# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from pydantic import Field

from .base_model import BaseModel


class DeleteCompound(BaseModel):
    delete_compound: "DeleteCompoundDeleteCompound" = Field(alias="deleteCompound")


class DeleteCompoundDeleteCompound(BaseModel):
    id: str
    name: str


DeleteCompound.model_rebuild()
