# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from .base_model import BaseModel


class Login(BaseModel):
    login: "LoginLogin"


class LoginLogin(BaseModel):
    token: str
    user: "LoginLoginUser"


class LoginLoginUser(BaseModel):
    id: str
    email: str
    name: Optional[str]
    role: str


Login.model_rebuild()
LoginLogin.model_rebuild()
