# Generated by ariadne-codegen
# Source: ../../src/graphql/schema.graphql

from enum import Enum


class UserProtocolStatus(str, Enum):
    draft = "draft"
    active = "active"
    archived = "archived"


class UserGoalType(str, Enum):
    sleep = "sleep"
    energy = "energy"
    fatLoss = "fatLoss"
    cognition = "cognition"
    longevity = "longevity"
    strength = "strength"
    stress = "stress"
    recovery = "recovery"
    other = "other"


class ProtocolStepItemType(str, Enum):
    PRODUCT = "PRODUCT"
    COMPOUND = "COMPOUND"
    ACTION = "ACTION"


class ProtocolTimeOfDay(str, Enum):
    morning = "morning"
    midday = "midday"
    evening = "evening"
    bedtime = "bedtime"
    any = "any"


class EvidenceRefType(str, Enum):
    episode = "episode"
    caseStudy = "caseStudy"
    article = "article"
    external = "external"


class ArticleSourceType(str, Enum):
    human_upgrade = "human_upgrade"
    external = "external"


class GoalType(str, Enum):
    sleep = "sleep"
    energy = "energy"
    fatLoss = "fatLoss"
    cognition = "cognition"
    longevity = "longevity"
    strength = "strength"
    stress = "stress"
    recovery = "recovery"
    other = "other"


class ExperienceLevel(str, Enum):
    beginner = "beginner"
    intermediate = "intermediate"
    advanced = "advanced"


class DietStyle(str, Enum):
    none = "none"
    keto = "keto"
    paleo = "paleo"
    vegan = "vegan"
    vegetarian = "vegetarian"
    mediterranean = "mediterranean"
    lowCarb = "lowCarb"
    omnivore = "omnivore"
    other = "other"


class TimeBudget(str, Enum):
    min5 = "min5"
    min15 = "min15"
    min30 = "min30"
    min60 = "min60"


class PreferredFormat(str, Enum):
    video = "video"
    summary = "summary"
    protocol = "protocol"
    caseStudy = "caseStudy"


class UserProvider(str, Enum):
    LOCAL = "LOCAL"
    GOOGLE = "GOOGLE"
    GITHUB = "GITHUB"
    APPLE = "APPLE"


class UserRole(str, Enum):
    ADMIN = "ADMIN"
    USER = "USER"


class ProtocolCategory(str, Enum):
    sleep = "sleep"
    circadian = "circadian"
    fitness = "fitness"
    nutrition = "nutrition"
    cognition = "cognition"
    stress = "stress"
    recovery = "recovery"
    longevity = "longevity"
    health = "health"
    other = "other"


class CaseStudySourceType(str, Enum):
    PUBMED = "PUBMED"
    CLINICAL_TRIAL = "CLINICAL_TRIAL"
    ARTICLE = "ARTICLE"
    OTHER = "OTHER"


class SavedEntityType(str, Enum):
    product = "product"
    compound = "compound"
    person = "person"
    business = "business"
    protocol = "protocol"
    episode = "episode"
    caseStudy = "caseStudy"
    article = "article"


class SaveSource(str, Enum):
    dashboard = "dashboard"
    episode = "episode"
    assistant = "assistant"
    search = "search"
    protocol_builder = "protocol_builder"
    profile = "profile"
    other = "other"
