# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpdateCompoundRelations(BaseModel):
    update_compound_relations: Optional[
        "UpdateCompoundRelationsUpdateCompoundRelations"
    ] = Field(alias="updateCompoundRelations")


class UpdateCompoundRelationsUpdateCompoundRelations(BaseModel):
    id: str
    name: str
    description: Optional[str]


UpdateCompoundRelations.model_rebuild()
