# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class EmbedPersonBio(BaseModel):
    embed_person_bio: "EmbedPersonBioEmbedPersonBio" = Field(alias="embedPersonBio")


class EmbedPersonBioEmbedPersonBio(BaseModel):
    id: str
    name: str
    bio: Optional[str]


EmbedPersonBio.model_rebuild()
