# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from .base_model import BaseModel


class Compounds(BaseModel):
    compounds: list["CompoundsCompounds"]


class CompoundsCompounds(BaseModel):
    id: str
    name: str
    description: Optional[str]
    aliases: list[str]


Compounds.model_rebuild()
