# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpdateEpisodeRelations(BaseModel):
    update_episode_relations: Optional[
        "UpdateEpisodeRelationsUpdateEpisodeRelations"
    ] = Field(alias="updateEpisodeRelations")


class UpdateEpisodeRelationsUpdateEpisodeRelations(BaseModel):
    id: str
    episode_title: Optional[str] = Field(alias="episodeTitle")
    channel_name: str = Field(alias="channelName")


UpdateEpisodeRelations.model_rebuild()
