# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpdateBusinessRelations(BaseModel):
    update_business_relations: Optional[
        "UpdateBusinessRelationsUpdateBusinessRelations"
    ] = Field(alias="updateBusinessRelations")


class UpdateBusinessRelationsUpdateBusinessRelations(BaseModel):
    id: str
    name: str
    description: Optional[str]
    website: Optional[str]


UpdateBusinessRelations.model_rebuild()
