# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from .base_model import BaseModel


class Products(BaseModel):
    products: list["ProductsProducts"]


class ProductsProducts(BaseModel):
    id: str
    name: str
    description: Optional[str]
    ingredients: list[str]


Products.model_rebuild()
