# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class CreatePerson(BaseModel):
    create_person: "CreatePersonCreatePerson" = Field(alias="createPerson")


class CreatePersonCreatePerson(BaseModel):
    id: str
    name: str
    role: Optional[str]
    bio: Optional[str]


CreatePerson.model_rebuild()
