# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class VectorSearchPeople(BaseModel):
    vector_search_people: Optional[list["VectorSearchPeopleVectorSearchPeople"]] = (
        Field(alias="vectorSearchPeople")
    )


class VectorSearchPeopleVectorSearchPeople(BaseModel):
    id: str
    name: str
    bio: str
    score: Optional[float]


VectorSearchPeople.model_rebuild()
