# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import SavedEntityType, SaveSource


class SaveEntity(BaseModel):
    save_entity: "SaveEntitySaveEntity" = Field(alias="saveEntity")


class SaveEntitySaveEntity(BaseModel):
    id: str
    user_id: str = Field(alias="userId")
    target_type: SavedEntityType = Field(alias="targetType")
    target_id: str = Field(alias="targetId")
    note: Optional[str]
    tags: list[str]
    pinned: bool
    source: Optional[SaveSource]
    created_at: Any = Field(alias="createdAt")
    updated_at: Any = Field(alias="updatedAt")


SaveEntity.model_rebuild()
