# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from pydantic import Field

from .base_model import BaseModel


class DeleteAllEpisodes(BaseModel):
    delete_all_episodes: "DeleteAllEpisodesDeleteAllEpisodes" = Field(
        alias="deleteAllEpisodes"
    )


class DeleteAllEpisodesDeleteAllEpisodes(BaseModel):
    deleted_count: int = Field(alias="deletedCount")


DeleteAllEpisodes.model_rebuild()
