# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpdateProductRelations(BaseModel):
    update_product_relations: Optional[
        "UpdateProductRelationsUpdateProductRelations"
    ] = Field(alias="updateProductRelations")


class UpdateProductRelationsUpdateProductRelations(BaseModel):
    id: str
    name: str
    description: Optional[str]


UpdateProductRelations.model_rebuild()
