# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from pydantic import Field

from .base_model import BaseModel


class DeleteBusiness(BaseModel):
    delete_business: "DeleteBusinessDeleteBusiness" = Field(alias="deleteBusiness")


class DeleteBusinessDeleteBusiness(BaseModel):
    deleted_count: int = Field(alias="deletedCount")


DeleteBusiness.model_rebuild()
