# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from .base_model import BaseModel


class Businesses(BaseModel):
    businesses: list["BusinessesBusinesses"]


class BusinessesBusinesses(BaseModel):
    id: str
    name: str
    description: Optional[str]
    website: Optional[str]


Businesses.model_rebuild()
