# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from pydantic import Field

from .base_model import BaseModel


class DeleteProtocol(BaseModel):
    delete_protocol: "DeleteProtocolDeleteProtocol" = Field(alias="deleteProtocol")


class DeleteProtocolDeleteProtocol(BaseModel):
    id: str
    name: str


DeleteProtocol.model_rebuild()
