# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class VectorSearchBusinesses(BaseModel):
    vector_search_businesses: Optional[
        list["VectorSearchBusinessesVectorSearchBusinesses"]
    ] = Field(alias="vectorSearchBusinesses")


class VectorSearchBusinessesVectorSearchBusinesses(BaseModel):
    id: str
    name: str
    description: str
    score: Optional[float]


VectorSearchBusinesses.model_rebuild()
