# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class DeleteEpisode(BaseModel):
    delete_episode: Optional["DeleteEpisodeDeleteEpisode"] = Field(
        alias="deleteEpisode"
    )


class DeleteEpisodeDeleteEpisode(BaseModel):
    id: str
    episode_title: Optional[str] = Field(alias="episodeTitle")


DeleteEpisode.model_rebuild()
