# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpsertUser(BaseModel):
    upsert_user: "UpsertUserUpsertUser" = Field(alias="upsertUser")


class UpsertUserUpsertUser(BaseModel):
    id: str
    email: str
    name: Optional[str]
    role: str


UpsertUser.model_rebuild()
