# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class CaseStudies(BaseModel):
    case_studies: list["CaseStudiesCaseStudies"] = Field(alias="caseStudies")


class CaseStudiesCaseStudies(BaseModel):
    id: str
    title: str
    summary: str
    url: Optional[str]


CaseStudies.model_rebuild()
