# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from pydantic import Field

from .base_model import BaseModel


class UnsaveEntity(BaseModel):
    unsave_entity: bool = Field(alias="unsaveEntity")
