# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from .base_model import BaseModel
from .enums import ProtocolCategory


class Protocols(BaseModel):
    protocols: list["ProtocolsProtocols"]


class ProtocolsProtocols(BaseModel):
    id: str
    name: str
    description: Optional[str]
    categories: list[ProtocolCategory]
    goals: list[str]


Protocols.model_rebuild()
