# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from .base_model import BaseModel


class Register(BaseModel):
    register: "RegisterRegister"


class RegisterRegister(BaseModel):
    token: str
    user: "RegisterRegisterUser"


class RegisterRegisterUser(BaseModel):
    id: str
    email: str
    name: Optional[str]
    role: str


Register.model_rebuild()
RegisterRegister.model_rebuild()
