# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from pydantic import Field

from .base_model import BaseModel


class DeleteProduct(BaseModel):
    delete_product: "DeleteProductDeleteProduct" = Field(alias="deleteProduct")


class DeleteProductDeleteProduct(BaseModel):
    id: str
    name: str


DeleteProduct.model_rebuild()
