# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class Episodes(BaseModel):
    episodes: list["EpisodesEpisodes"]


class EpisodesEpisodes(BaseModel):
    id: str
    episode_title: Optional[str] = Field(alias="episodeTitle")
    channel_name: str = Field(alias="channelName")
    episode_number: Optional[int] = Field(alias="episodeNumber")
    published_at: Optional[Any] = Field(alias="publishedAt")


Episodes.model_rebuild()
