# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpdateBusiness(BaseModel):
    update_business: Optional["UpdateBusinessUpdateBusiness"] = Field(
        alias="updateBusiness"
    )


class UpdateBusinessUpdateBusiness(BaseModel):
    id: str
    name: str
    description: Optional[str]
    website: Optional[str]


UpdateBusiness.model_rebuild()
