# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class CreateCompound(BaseModel):
    create_compound: "CreateCompoundCreateCompound" = Field(alias="createCompound")


class CreateCompoundCreateCompound(BaseModel):
    id: str
    name: str
    description: Optional[str]
    aliases: list[str]


CreateCompound.model_rebuild()
