# Generated by ariadne-codegen

from .all_users import AllUsers, AllUsersAllUsers
from .async_base_client import AsyncBaseClient
from .base_model import BaseModel, Upload
from .business import (
    Business,
    BusinessBusiness,
    BusinessBusinessExecutives,
    BusinessBusinessExecutivesPerson,
    BusinessBusinessMediaLinks,
    BusinessBusinessOwners,
    BusinessBusinessProducts,
    BusinessBusinessSponsoredEpisodes,
)
from .businesses import Businesses, BusinessesBusinesses
from .case_studies import CaseStudies, CaseStudiesCaseStudies
from .case_study import (
    CaseStudy,
    CaseStudyCaseStudy,
    CaseStudyCaseStudyCompounds,
    CaseStudyCaseStudyEpisodes,
    CaseStudyCaseStudyMediaLinks,
    CaseStudyCaseStudyProducts,
    CaseStudyCaseStudyProtocols,
)
from .client import Client
from .compound import (
    Compound,
    CompoundCompound,
    CompoundCompoundCaseStudies,
    CompoundCompoundMediaLinks,
    CompoundCompoundProducts,
)
from .compounds import Compounds, CompoundsCompounds
from .create_business_with_relations import (
    CreateBusinessWithRelations,
    CreateBusinessWithRelationsCreateBusinessWithRelations,
)
from .create_case_study import CreateCaseStudy, CreateCaseStudyCreateCaseStudy
from .create_compound import CreateCompound, CreateCompoundCreateCompound
from .create_episode import CreateEpisode, CreateEpisodeCreateEpisode
from .create_person import CreatePerson, CreatePersonCreatePerson
from .create_product import CreateProduct, CreateProductCreateProduct
from .create_protocol import CreateProtocol, CreateProtocolCreateProtocol
from .create_user_protocol import (
    CreateUserProtocol,
    CreateUserProtocolCreateUserProtocol,
    CreateUserProtocolCreateUserProtocolEvidenceRefs,
    CreateUserProtocolCreateUserProtocolEvidenceRefsEvidenceRefEntityArticle,
    CreateUserProtocolCreateUserProtocolEvidenceRefsEvidenceRefEntityCaseStudy,
    CreateUserProtocolCreateUserProtocolEvidenceRefsEvidenceRefEntityEpisode,
    CreateUserProtocolCreateUserProtocolEvidenceRefsEvidenceRefEntityExternal,
    CreateUserProtocolCreateUserProtocolSafety,
    CreateUserProtocolCreateUserProtocolStepsStructured,
    CreateUserProtocolCreateUserProtocolStepsStructuredItems,
    CreateUserProtocolCreateUserProtocolStepsStructuredItemsItemEntityCompound,
    CreateUserProtocolCreateUserProtocolStepsStructuredItemsItemEntityProduct,
)
from .delete_all_episodes import DeleteAllEpisodes, DeleteAllEpisodesDeleteAllEpisodes
from .delete_business import DeleteBusiness, DeleteBusinessDeleteBusiness
from .delete_compound import DeleteCompound, DeleteCompoundDeleteCompound
from .delete_episode import DeleteEpisode, DeleteEpisodeDeleteEpisode
from .delete_person import DeletePerson, DeletePersonDeletePerson
from .delete_product import DeleteProduct, DeleteProductDeleteProduct
from .delete_protocol import DeleteProtocol, DeleteProtocolDeleteProtocol
from .delete_user import DeleteUser, DeleteUserDeleteUser
from .delete_user_profile import DeleteUserProfile, DeleteUserProfileDeleteUserProfile
from .delete_user_protocol import DeleteUserProtocol
from .embed_business_description import (
    EmbedBusinessDescription,
    EmbedBusinessDescriptionEmbedBusinessDescription,
)
from .embed_person_bio import EmbedPersonBio, EmbedPersonBioEmbedPersonBio
from .embed_product_description import (
    EmbedProductDescription,
    EmbedProductDescriptionEmbedProductDescription,
)
from .enums import (
    ArticleSourceType,
    CaseStudySourceType,
    DietStyle,
    EvidenceRefType,
    ExperienceLevel,
    GoalType,
    PreferredFormat,
    ProtocolCategory,
    ProtocolStepItemType,
    ProtocolTimeOfDay,
    SavedEntityType,
    SaveSource,
    TimeBudget,
    UserGoalType,
    UserProtocolStatus,
    UserProvider,
    UserRole,
)
from .episode import (
    Episode,
    EpisodeEpisode,
    EpisodeEpisodeGuests,
    EpisodeEpisodeMediaLinks,
    EpisodeEpisodeProtocols,
    EpisodeEpisodeSponsorBusinesses,
    EpisodeEpisodeSponsorLinkObjects,
    EpisodeEpisodeWebPageTimelines,
)
from .episodes import Episodes, EpisodesEpisodes
from .exceptions import (
    GraphQLClientError,
    GraphQLClientGraphQLError,
    GraphQLClientGraphQLMultiError,
    GraphQLClientHttpError,
    GraphQLClientInvalidResponseError,
)
from .input_types import (
    BusinessCreateRelationsInput,
    BusinessEpisodeNestedInput,
    BusinessExecutiveNestedInput,
    BusinessExecutiveRelationInput,
    BusinessOwnerNestedInput,
    BusinessProductNestedInput,
    BusinessUpdateRelationFieldsInput,
    BusinessUpdateWithIdsInput,
    CaseStudyCreateWithOptionalIdsInput,
    CaseStudyUpdateWithOptionalIdsInput,
    CompoundCreateWithIdsInput,
    CompoundProductNestedInput,
    CompoundUpdateRelationFieldsInput,
    CompoundUpdateWithIdsInput,
    CreateUserProtocolInput,
    CursorPageInput,
    EntityPreferencesInput,
    EpisodeCreateWithIdsInput,
    EpisodeGuestNestedInput,
    EpisodeSponsorBusinessNestedInput,
    EpisodeUpdateRelationFieldsInput,
    EpisodeUpdateWithIdsInput,
    EvidenceRefInput,
    MediaLinkInput,
    PersonCreateInput,
    PersonUpdateInput,
    ProductCompoundNestedInput,
    ProductCreateWithIdsInput,
    ProductProtocolNestedInput,
    ProductUpdateRelationFieldsInput,
    ProductUpdateWithIdsInput,
    ProtocolCompoundNestedInput,
    ProtocolCreateWithIdsInput,
    ProtocolProductNestedInput,
    ProtocolStepGroupInput,
    ProtocolStepItemInput,
    ProtocolUpdateRelationFieldsInput,
    ProtocolUpdateWithIdsInput,
    SafetyBucketInput,
    SavedEntitiesFilterInput,
    SaveEntityInput,
    SponsorLinkObjectInput,
    UnsaveEntityInput,
    UpdateUserProtocolInput,
    UserCreateInput,
    UserGoalInput,
    UserProfileUpsertInput,
    UserProtocolsFilterInput,
    UserUpsertInput,
    VectorSearchArgs,
    WebPageTimelineInput,
)
from .login import Login, LoginLogin, LoginLoginUser
from .me import Me, MeMe, MeMeProfile, MeMeProfileEntityPreferences, MeMeProfileGoals
from .my_profile import (
    MyProfile,
    MyProfileMyProfile,
    MyProfileMyProfileEntityPreferences,
    MyProfileMyProfileGoals,
)
from .my_user_protocols import (
    MyUserProtocols,
    MyUserProtocolsMyUserProtocols,
    MyUserProtocolsMyUserProtocolsEdges,
    MyUserProtocolsMyUserProtocolsEdgesNode,
    MyUserProtocolsMyUserProtocolsEdgesNodeEvidenceRefs,
    MyUserProtocolsMyUserProtocolsEdgesNodeEvidenceRefsEvidenceRefEntityArticle,
    MyUserProtocolsMyUserProtocolsEdgesNodeEvidenceRefsEvidenceRefEntityCaseStudy,
    MyUserProtocolsMyUserProtocolsEdgesNodeEvidenceRefsEvidenceRefEntityEpisode,
    MyUserProtocolsMyUserProtocolsEdgesNodeEvidenceRefsEvidenceRefEntityExternal,
    MyUserProtocolsMyUserProtocolsEdgesNodeSafety,
    MyUserProtocolsMyUserProtocolsEdgesNodeStepsStructured,
    MyUserProtocolsMyUserProtocolsEdgesNodeStepsStructuredItems,
    MyUserProtocolsMyUserProtocolsEdgesNodeStepsStructuredItemsItemEntityCompound,
    MyUserProtocolsMyUserProtocolsEdgesNodeStepsStructuredItemsItemEntityProduct,
    MyUserProtocolsMyUserProtocolsPageInfo,
)
from .people import People, PeoplePeople
from .person import (
    Person,
    PersonPerson,
    PersonPersonBusinesses,
    PersonPersonEpisodes,
    PersonPersonMediaLinks,
)
from .product import (
    Product,
    ProductProduct,
    ProductProductBusiness,
    ProductProductCompounds,
    ProductProductMediaLinks,
    ProductProductSponsorEpisodes,
)
from .products import Products, ProductsProducts
from .protocol import (
    Protocol,
    ProtocolProtocol,
    ProtocolProtocolCompounds,
    ProtocolProtocolEvidenceRefs,
    ProtocolProtocolEvidenceRefsEvidenceRefEntityArticle,
    ProtocolProtocolEvidenceRefsEvidenceRefEntityCaseStudy,
    ProtocolProtocolEvidenceRefsEvidenceRefEntityEpisode,
    ProtocolProtocolEvidenceRefsEvidenceRefEntityExternal,
    ProtocolProtocolProducts,
    ProtocolProtocolSafety,
    ProtocolProtocolStepsStructured,
    ProtocolProtocolStepsStructuredItems,
    ProtocolProtocolStepsStructuredItemsItemEntityCompound,
    ProtocolProtocolStepsStructuredItemsItemEntityProduct,
)
from .protocols import Protocols, ProtocolsProtocols
from .register import Register, RegisterRegister, RegisterRegisterUser
from .save_entity import SaveEntity, SaveEntitySaveEntity
from .saved_entities import (
    SavedEntities,
    SavedEntitiesSavedEntities,
    SavedEntitiesSavedEntitiesEdges,
    SavedEntitiesSavedEntitiesEdgesNode,
    SavedEntitiesSavedEntitiesEdgesNodeTargetArticle,
    SavedEntitiesSavedEntitiesEdgesNodeTargetBusiness,
    SavedEntitiesSavedEntitiesEdgesNodeTargetCaseStudy,
    SavedEntitiesSavedEntitiesEdgesNodeTargetCompound,
    SavedEntitiesSavedEntitiesEdgesNodeTargetEpisode,
    SavedEntitiesSavedEntitiesEdgesNodeTargetPerson,
    SavedEntitiesSavedEntitiesEdgesNodeTargetProduct,
    SavedEntitiesSavedEntitiesEdgesNodeTargetProtocol,
    SavedEntitiesSavedEntitiesPageInfo,
)
from .unsave_entity import UnsaveEntity
from .update_business import UpdateBusiness, UpdateBusinessUpdateBusiness
from .update_business_relations import (
    UpdateBusinessRelations,
    UpdateBusinessRelationsUpdateBusinessRelations,
)
from .update_case_study import UpdateCaseStudy, UpdateCaseStudyUpdateCaseStudy
from .update_compound import UpdateCompound, UpdateCompoundUpdateCompound
from .update_compound_relations import (
    UpdateCompoundRelations,
    UpdateCompoundRelationsUpdateCompoundRelations,
)
from .update_episode import UpdateEpisode, UpdateEpisodeUpdateEpisode
from .update_episode_relations import (
    UpdateEpisodeRelations,
    UpdateEpisodeRelationsUpdateEpisodeRelations,
)
from .update_person import UpdatePerson, UpdatePersonUpdatePerson
from .update_product import UpdateProduct, UpdateProductUpdateProduct
from .update_product_relations import (
    UpdateProductRelations,
    UpdateProductRelationsUpdateProductRelations,
)
from .update_protocol import (
    UpdateProtocol,
    UpdateProtocolUpdateProtocol,
    UpdateProtocolUpdateProtocolCompounds,
    UpdateProtocolUpdateProtocolEvidenceRefs,
    UpdateProtocolUpdateProtocolEvidenceRefsEvidenceRefEntityArticle,
    UpdateProtocolUpdateProtocolEvidenceRefsEvidenceRefEntityCaseStudy,
    UpdateProtocolUpdateProtocolEvidenceRefsEvidenceRefEntityEpisode,
    UpdateProtocolUpdateProtocolEvidenceRefsEvidenceRefEntityExternal,
    UpdateProtocolUpdateProtocolProducts,
    UpdateProtocolUpdateProtocolSafety,
    UpdateProtocolUpdateProtocolStepsStructured,
    UpdateProtocolUpdateProtocolStepsStructuredItems,
    UpdateProtocolUpdateProtocolStepsStructuredItemsItemEntityCompound,
    UpdateProtocolUpdateProtocolStepsStructuredItemsItemEntityProduct,
)
from .update_protocol_relations import (
    UpdateProtocolRelations,
    UpdateProtocolRelationsUpdateProtocolRelations,
    UpdateProtocolRelationsUpdateProtocolRelationsCompounds,
    UpdateProtocolRelationsUpdateProtocolRelationsProducts,
)
from .update_user_protocol import (
    UpdateUserProtocol,
    UpdateUserProtocolUpdateUserProtocol,
    UpdateUserProtocolUpdateUserProtocolEvidenceRefs,
    UpdateUserProtocolUpdateUserProtocolEvidenceRefsEvidenceRefEntityArticle,
    UpdateUserProtocolUpdateUserProtocolEvidenceRefsEvidenceRefEntityCaseStudy,
    UpdateUserProtocolUpdateUserProtocolEvidenceRefsEvidenceRefEntityEpisode,
    UpdateUserProtocolUpdateUserProtocolEvidenceRefsEvidenceRefEntityExternal,
    UpdateUserProtocolUpdateUserProtocolSafety,
    UpdateUserProtocolUpdateUserProtocolStepsStructured,
    UpdateUserProtocolUpdateUserProtocolStepsStructuredItems,
    UpdateUserProtocolUpdateUserProtocolStepsStructuredItemsItemEntityCompound,
    UpdateUserProtocolUpdateUserProtocolStepsStructuredItemsItemEntityProduct,
)
from .upsert_user import UpsertUser, UpsertUserUpsertUser
from .upsert_user_profile import (
    UpsertUserProfile,
    UpsertUserProfileUpsertUserProfile,
    UpsertUserProfileUpsertUserProfileEntityPreferences,
    UpsertUserProfileUpsertUserProfileGoals,
)
from .vector_search_businesses import (
    VectorSearchBusinesses,
    VectorSearchBusinessesVectorSearchBusinesses,
)
from .vector_search_people import (
    VectorSearchPeople,
    VectorSearchPeopleVectorSearchPeople,
)
from .vector_search_products import (
    VectorSearchProducts,
    VectorSearchProductsVectorSearchProducts,
)

__all__ = [
    "AllUsers",
    "AllUsersAllUsers",
    "ArticleSourceType",
    "AsyncBaseClient",
    "BaseModel",
    "Business",
    "BusinessBusiness",
    "BusinessBusinessExecutives",
    "BusinessBusinessExecutivesPerson",
    "BusinessBusinessMediaLinks",
    "BusinessBusinessOwners",
    "BusinessBusinessProducts",
    "BusinessBusinessSponsoredEpisodes",
    "BusinessCreateRelationsInput",
    "BusinessEpisodeNestedInput",
    "BusinessExecutiveNestedInput",
    "BusinessExecutiveRelationInput",
    "BusinessOwnerNestedInput",
    "BusinessProductNestedInput",
    "BusinessUpdateRelationFieldsInput",
    "BusinessUpdateWithIdsInput",
    "Businesses",
    "BusinessesBusinesses",
    "CaseStudies",
    "CaseStudiesCaseStudies",
    "CaseStudy",
    "CaseStudyCaseStudy",
    "CaseStudyCaseStudyCompounds",
    "CaseStudyCaseStudyEpisodes",
    "CaseStudyCaseStudyMediaLinks",
    "CaseStudyCaseStudyProducts",
    "CaseStudyCaseStudyProtocols",
    "CaseStudyCreateWithOptionalIdsInput",
    "CaseStudySourceType",
    "CaseStudyUpdateWithOptionalIdsInput",
    "Client",
    "Compound",
    "CompoundCompound",
    "CompoundCompoundCaseStudies",
    "CompoundCompoundMediaLinks",
    "CompoundCompoundProducts",
    "CompoundCreateWithIdsInput",
    "CompoundProductNestedInput",
    "CompoundUpdateRelationFieldsInput",
    "CompoundUpdateWithIdsInput",
    "Compounds",
    "CompoundsCompounds",
    "CreateBusinessWithRelations",
    "CreateBusinessWithRelationsCreateBusinessWithRelations",
    "CreateCaseStudy",
    "CreateCaseStudyCreateCaseStudy",
    "CreateCompound",
    "CreateCompoundCreateCompound",
    "CreateEpisode",
    "CreateEpisodeCreateEpisode",
    "CreatePerson",
    "CreatePersonCreatePerson",
    "CreateProduct",
    "CreateProductCreateProduct",
    "CreateProtocol",
    "CreateProtocolCreateProtocol",
    "CreateUserProtocol",
    "CreateUserProtocolCreateUserProtocol",
    "CreateUserProtocolCreateUserProtocolEvidenceRefs",
    "CreateUserProtocolCreateUserProtocolEvidenceRefsEvidenceRefEntityArticle",
    "CreateUserProtocolCreateUserProtocolEvidenceRefsEvidenceRefEntityCaseStudy",
    "CreateUserProtocolCreateUserProtocolEvidenceRefsEvidenceRefEntityEpisode",
    "CreateUserProtocolCreateUserProtocolEvidenceRefsEvidenceRefEntityExternal",
    "CreateUserProtocolCreateUserProtocolSafety",
    "CreateUserProtocolCreateUserProtocolStepsStructured",
    "CreateUserProtocolCreateUserProtocolStepsStructuredItems",
    "CreateUserProtocolCreateUserProtocolStepsStructuredItemsItemEntityCompound",
    "CreateUserProtocolCreateUserProtocolStepsStructuredItemsItemEntityProduct",
    "CreateUserProtocolInput",
    "CursorPageInput",
    "DeleteAllEpisodes",
    "DeleteAllEpisodesDeleteAllEpisodes",
    "DeleteBusiness",
    "DeleteBusinessDeleteBusiness",
    "DeleteCompound",
    "DeleteCompoundDeleteCompound",
    "DeleteEpisode",
    "DeleteEpisodeDeleteEpisode",
    "DeletePerson",
    "DeletePersonDeletePerson",
    "DeleteProduct",
    "DeleteProductDeleteProduct",
    "DeleteProtocol",
    "DeleteProtocolDeleteProtocol",
    "DeleteUser",
    "DeleteUserDeleteUser",
    "DeleteUserProfile",
    "DeleteUserProfileDeleteUserProfile",
    "DeleteUserProtocol",
    "DietStyle",
    "EmbedBusinessDescription",
    "EmbedBusinessDescriptionEmbedBusinessDescription",
    "EmbedPersonBio",
    "EmbedPersonBioEmbedPersonBio",
    "EmbedProductDescription",
    "EmbedProductDescriptionEmbedProductDescription",
    "EntityPreferencesInput",
    "Episode",
    "EpisodeCreateWithIdsInput",
    "EpisodeEpisode",
    "EpisodeEpisodeGuests",
    "EpisodeEpisodeMediaLinks",
    "EpisodeEpisodeProtocols",
    "EpisodeEpisodeSponsorBusinesses",
    "EpisodeEpisodeSponsorLinkObjects",
    "EpisodeEpisodeWebPageTimelines",
    "EpisodeGuestNestedInput",
    "EpisodeSponsorBusinessNestedInput",
    "EpisodeUpdateRelationFieldsInput",
    "EpisodeUpdateWithIdsInput",
    "Episodes",
    "EpisodesEpisodes",
    "EvidenceRefInput",
    "EvidenceRefType",
    "ExperienceLevel",
    "GoalType",
    "GraphQLClientError",
    "GraphQLClientGraphQLError",
    "GraphQLClientGraphQLMultiError",
    "GraphQLClientHttpError",
    "GraphQLClientInvalidResponseError",
    "Login",
    "LoginLogin",
    "LoginLoginUser",
    "Me",
    "MeMe",
    "MeMeProfile",
    "MeMeProfileEntityPreferences",
    "MeMeProfileGoals",
    "MediaLinkInput",
    "MyProfile",
    "MyProfileMyProfile",
    "MyProfileMyProfileEntityPreferences",
    "MyProfileMyProfileGoals",
    "MyUserProtocols",
    "MyUserProtocolsMyUserProtocols",
    "MyUserProtocolsMyUserProtocolsEdges",
    "MyUserProtocolsMyUserProtocolsEdgesNode",
    "MyUserProtocolsMyUserProtocolsEdgesNodeEvidenceRefs",
    "MyUserProtocolsMyUserProtocolsEdgesNodeEvidenceRefsEvidenceRefEntityArticle",
    "MyUserProtocolsMyUserProtocolsEdgesNodeEvidenceRefsEvidenceRefEntityCaseStudy",
    "MyUserProtocolsMyUserProtocolsEdgesNodeEvidenceRefsEvidenceRefEntityEpisode",
    "MyUserProtocolsMyUserProtocolsEdgesNodeEvidenceRefsEvidenceRefEntityExternal",
    "MyUserProtocolsMyUserProtocolsEdgesNodeSafety",
    "MyUserProtocolsMyUserProtocolsEdgesNodeStepsStructured",
    "MyUserProtocolsMyUserProtocolsEdgesNodeStepsStructuredItems",
    "MyUserProtocolsMyUserProtocolsEdgesNodeStepsStructuredItemsItemEntityCompound",
    "MyUserProtocolsMyUserProtocolsEdgesNodeStepsStructuredItemsItemEntityProduct",
    "MyUserProtocolsMyUserProtocolsPageInfo",
    "People",
    "PeoplePeople",
    "Person",
    "PersonCreateInput",
    "PersonPerson",
    "PersonPersonBusinesses",
    "PersonPersonEpisodes",
    "PersonPersonMediaLinks",
    "PersonUpdateInput",
    "PreferredFormat",
    "Product",
    "ProductCompoundNestedInput",
    "ProductCreateWithIdsInput",
    "ProductProduct",
    "ProductProductBusiness",
    "ProductProductCompounds",
    "ProductProductMediaLinks",
    "ProductProductSponsorEpisodes",
    "ProductProtocolNestedInput",
    "ProductUpdateRelationFieldsInput",
    "ProductUpdateWithIdsInput",
    "Products",
    "ProductsProducts",
    "Protocol",
    "ProtocolCategory",
    "ProtocolCompoundNestedInput",
    "ProtocolCreateWithIdsInput",
    "ProtocolProductNestedInput",
    "ProtocolProtocol",
    "ProtocolProtocolCompounds",
    "ProtocolProtocolEvidenceRefs",
    "ProtocolProtocolEvidenceRefsEvidenceRefEntityArticle",
    "ProtocolProtocolEvidenceRefsEvidenceRefEntityCaseStudy",
    "ProtocolProtocolEvidenceRefsEvidenceRefEntityEpisode",
    "ProtocolProtocolEvidenceRefsEvidenceRefEntityExternal",
    "ProtocolProtocolProducts",
    "ProtocolProtocolSafety",
    "ProtocolProtocolStepsStructured",
    "ProtocolProtocolStepsStructuredItems",
    "ProtocolProtocolStepsStructuredItemsItemEntityCompound",
    "ProtocolProtocolStepsStructuredItemsItemEntityProduct",
    "ProtocolStepGroupInput",
    "ProtocolStepItemInput",
    "ProtocolStepItemType",
    "ProtocolTimeOfDay",
    "ProtocolUpdateRelationFieldsInput",
    "ProtocolUpdateWithIdsInput",
    "Protocols",
    "ProtocolsProtocols",
    "Register",
    "RegisterRegister",
    "RegisterRegisterUser",
    "SafetyBucketInput",
    "SaveEntity",
    "SaveEntityInput",
    "SaveEntitySaveEntity",
    "SaveSource",
    "SavedEntities",
    "SavedEntitiesFilterInput",
    "SavedEntitiesSavedEntities",
    "SavedEntitiesSavedEntitiesEdges",
    "SavedEntitiesSavedEntitiesEdgesNode",
    "SavedEntitiesSavedEntitiesEdgesNodeTargetArticle",
    "SavedEntitiesSavedEntitiesEdgesNodeTargetBusiness",
    "SavedEntitiesSavedEntitiesEdgesNodeTargetCaseStudy",
    "SavedEntitiesSavedEntitiesEdgesNodeTargetCompound",
    "SavedEntitiesSavedEntitiesEdgesNodeTargetEpisode",
    "SavedEntitiesSavedEntitiesEdgesNodeTargetPerson",
    "SavedEntitiesSavedEntitiesEdgesNodeTargetProduct",
    "SavedEntitiesSavedEntitiesEdgesNodeTargetProtocol",
    "SavedEntitiesSavedEntitiesPageInfo",
    "SavedEntityType",
    "SponsorLinkObjectInput",
    "TimeBudget",
    "UnsaveEntity",
    "UnsaveEntityInput",
    "UpdateBusiness",
    "UpdateBusinessRelations",
    "UpdateBusinessRelationsUpdateBusinessRelations",
    "UpdateBusinessUpdateBusiness",
    "UpdateCaseStudy",
    "UpdateCaseStudyUpdateCaseStudy",
    "UpdateCompound",
    "UpdateCompoundRelations",
    "UpdateCompoundRelationsUpdateCompoundRelations",
    "UpdateCompoundUpdateCompound",
    "UpdateEpisode",
    "UpdateEpisodeRelations",
    "UpdateEpisodeRelationsUpdateEpisodeRelations",
    "UpdateEpisodeUpdateEpisode",
    "UpdatePerson",
    "UpdatePersonUpdatePerson",
    "UpdateProduct",
    "UpdateProductRelations",
    "UpdateProductRelationsUpdateProductRelations",
    "UpdateProductUpdateProduct",
    "UpdateProtocol",
    "UpdateProtocolRelations",
    "UpdateProtocolRelationsUpdateProtocolRelations",
    "UpdateProtocolRelationsUpdateProtocolRelationsCompounds",
    "UpdateProtocolRelationsUpdateProtocolRelationsProducts",
    "UpdateProtocolUpdateProtocol",
    "UpdateProtocolUpdateProtocolCompounds",
    "UpdateProtocolUpdateProtocolEvidenceRefs",
    "UpdateProtocolUpdateProtocolEvidenceRefsEvidenceRefEntityArticle",
    "UpdateProtocolUpdateProtocolEvidenceRefsEvidenceRefEntityCaseStudy",
    "UpdateProtocolUpdateProtocolEvidenceRefsEvidenceRefEntityEpisode",
    "UpdateProtocolUpdateProtocolEvidenceRefsEvidenceRefEntityExternal",
    "UpdateProtocolUpdateProtocolProducts",
    "UpdateProtocolUpdateProtocolSafety",
    "UpdateProtocolUpdateProtocolStepsStructured",
    "UpdateProtocolUpdateProtocolStepsStructuredItems",
    "UpdateProtocolUpdateProtocolStepsStructuredItemsItemEntityCompound",
    "UpdateProtocolUpdateProtocolStepsStructuredItemsItemEntityProduct",
    "UpdateUserProtocol",
    "UpdateUserProtocolInput",
    "UpdateUserProtocolUpdateUserProtocol",
    "UpdateUserProtocolUpdateUserProtocolEvidenceRefs",
    "UpdateUserProtocolUpdateUserProtocolEvidenceRefsEvidenceRefEntityArticle",
    "UpdateUserProtocolUpdateUserProtocolEvidenceRefsEvidenceRefEntityCaseStudy",
    "UpdateUserProtocolUpdateUserProtocolEvidenceRefsEvidenceRefEntityEpisode",
    "UpdateUserProtocolUpdateUserProtocolEvidenceRefsEvidenceRefEntityExternal",
    "UpdateUserProtocolUpdateUserProtocolSafety",
    "UpdateUserProtocolUpdateUserProtocolStepsStructured",
    "UpdateUserProtocolUpdateUserProtocolStepsStructuredItems",
    "UpdateUserProtocolUpdateUserProtocolStepsStructuredItemsItemEntityCompound",
    "UpdateUserProtocolUpdateUserProtocolStepsStructuredItemsItemEntityProduct",
    "Upload",
    "UpsertUser",
    "UpsertUserProfile",
    "UpsertUserProfileUpsertUserProfile",
    "UpsertUserProfileUpsertUserProfileEntityPreferences",
    "UpsertUserProfileUpsertUserProfileGoals",
    "UpsertUserUpsertUser",
    "UserCreateInput",
    "UserGoalInput",
    "UserGoalType",
    "UserProfileUpsertInput",
    "UserProtocolStatus",
    "UserProtocolsFilterInput",
    "UserProvider",
    "UserRole",
    "UserUpsertInput",
    "VectorSearchArgs",
    "VectorSearchBusinesses",
    "VectorSearchBusinessesVectorSearchBusinesses",
    "VectorSearchPeople",
    "VectorSearchPeopleVectorSearchPeople",
    "VectorSearchProducts",
    "VectorSearchProductsVectorSearchProducts",
    "WebPageTimelineInput",
]
