# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from .base_model import BaseModel


class People(BaseModel):
    people: list["PeoplePeople"]


class PeoplePeople(BaseModel):
    id: str
    name: str
    role: Optional[str]


People.model_rebuild()
