# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from pydantic import Field

from .base_model import BaseModel


class DeletePerson(BaseModel):
    delete_person: "DeletePersonDeletePerson" = Field(alias="deletePerson")


class DeletePersonDeletePerson(BaseModel):
    id: str
    name: str


DeletePerson.model_rebuild()
