# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from pydantic import Field

from .base_model import BaseModel


class DeleteUserProfile(BaseModel):
    delete_user_profile: "DeleteUserProfileDeleteUserProfile" = Field(
        alias="deleteUserProfile"
    )


class DeleteUserProfileDeleteUserProfile(BaseModel):
    deleted_count: int = Field(alias="deletedCount")


DeleteUserProfile.model_rebuild()
