# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class CreateEpisode(BaseModel):
    create_episode: "CreateEpisodeCreateEpisode" = Field(alias="createEpisode")


class CreateEpisodeCreateEpisode(BaseModel):
    id: str
    episode_title: Optional[str] = Field(alias="episodeTitle")
    channel_name: str = Field(alias="channelName")
    episode_number: Optional[int] = Field(alias="episodeNumber")


CreateEpisode.model_rebuild()
