# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class VectorSearchProducts(BaseModel):
    vector_search_products: Optional[
        list["VectorSearchProductsVectorSearchProducts"]
    ] = Field(alias="vectorSearchProducts")


class VectorSearchProductsVectorSearchProducts(BaseModel):
    id: str
    name: str
    description: str
    score: Optional[float]


VectorSearchProducts.model_rebuild()
