# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from pydantic import Field

from .base_model import BaseModel


class DeleteUserProtocol(BaseModel):
    delete_user_protocol: bool = Field(alias="deleteUserProtocol")
