# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class CreateProduct(BaseModel):
    create_product: "CreateProductCreateProduct" = Field(alias="createProduct")


class CreateProductCreateProduct(BaseModel):
    id: str
    name: str
    description: Optional[str]
    ingredients: list[str]


CreateProduct.model_rebuild()
