# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class EmbedProductDescription(BaseModel):
    embed_product_description: "EmbedProductDescriptionEmbedProductDescription" = Field(
        alias="embedProductDescription"
    )


class EmbedProductDescriptionEmbedProductDescription(BaseModel):
    id: str
    name: str
    description: Optional[str]


EmbedProductDescription.model_rebuild()
